@@ -22,8 +22,7 @@ DIR* opendir(const char* mask)
     DIR* dir;
     char *ch;
 
-    dir = malloc(sizeof(DIR));
-    if (!dir) return NULL;
+    if ((dir = malloc(sizeof(DIR))) == NULL) return NULL;
     dir->_first_time = 1;
     dir->_handle = -1;
     strcpy(dir->_mask,mask);
