@@ -3,7 +3,7 @@
  *
  *  protocol.c is a part of binkd project
  *
- *  Copyright (C) 1996-1997  Dima Maloff, 5047/13
+ *  Copyright (C) 1996-1998  Dima Maloff, 5047/13
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -91,6 +91,7 @@
 #include "protoco2.h"
 #include "assert.h"
 #include "binlog.h"
+#include "setpttl.h"
 
 /*
  * Fills <<state>> with initial values, allocates buffers, etc.
@@ -105,10 +106,9 @@ static int init_protocol (STATE *state, SOCKET socket, FTN_NODE *to)
   state->off_req_sent = 0;
   state->inbound = inbound_nonsecure;
   state->io_error = 0;
-  state->ibuf = malloc (MAX_BLKSIZE + BLK_HDR_SIZE + 1);
+  state->ibuf = xalloc (MAX_BLKSIZE + BLK_HDR_SIZE + 1);
   state->isize = -1;
-  state->obuf = malloc (MAX_BLKSIZE + BLK_HDR_SIZE + 1);
-  assert (state->ibuf != 0 && state->obuf != 0);
+  state->obuf = xalloc (MAX_BLKSIZE + BLK_HDR_SIZE + 1);
   state->optr = 0;
   state->oleft = 0;
   state->bytes_sent = state->bytes_rcvd = 0;
@@ -206,14 +206,13 @@ static void msg_send2 (STATE *state, t_msg m, char *s1, char *s2)
   if (!s2)
     s2 = "";
 
-  state->msgs = realloc (state->msgs, sizeof (BMSG) * (state->n_msgs + 1));
-  assert (state->msgs != 0);
+  state->msgs = xrealloc (state->msgs, sizeof (BMSG) * (state->n_msgs + 1));
   state->msgs[state->n_msgs].t = m;
   /* We will check for sz correctness (sz <= 0x7fff) later, when sending
    * messages from the queue. */
   state->msgs[state->n_msgs].sz = strlen (s1) + strlen (s2) + 1;
   state->msgs[state->n_msgs].s =
-    malloc (state->msgs[state->n_msgs].sz + 3);
+    xalloc (state->msgs[state->n_msgs].sz + 3);
 
   mkhdr (state->msgs[state->n_msgs].s,
 	 (unsigned) (state->msgs[state->n_msgs].sz | 0x8000));
@@ -250,9 +249,8 @@ static void msg_sendf (STATE *state, t_msg m, char *s,...)
 static void current_file_was_sent (STATE *state)
 {
   fclose (state->out.f);
-  state->sent_fls = realloc (state->sent_fls,
-			     ++(state->n_sent_fls) * sizeof (TFILE));
-  assert (state->sent_fls != 0);
+  state->sent_fls = xrealloc (state->sent_fls,
+			      ++(state->n_sent_fls) * sizeof (TFILE));
   memcpy (state->sent_fls + state->n_sent_fls - 1,
 	  &state->out,
 	  sizeof (TFILE));
@@ -466,8 +464,8 @@ static int remove_from_spool (STATE *state, char *flopath,
       curr_offset = ftell (flo);
       if (!fgets (buf, MAXPATHLEN, flo))
 	break;
-      for (i = 0; !isspace (buf[i]); ++i);
-      buf[i] = 0;
+      for (i = strlen (buf) - 1; i > 0 && isspace (buf[i]); --i)
+	buf[i] = 0;
 
       if (file && (!strcmp (file, buf) ||
 		 ((*buf == '^' || *buf == '#') && !strcmp (file, buf + 1))))
@@ -549,7 +547,7 @@ static int NUL (STATE *state, char *buf, int sz)
 {
   char *s, *a, *b;
 
-  Log (3, "%s", s = strquote (buf));
+  Log (3, "%s", s = strquote (buf, SQ_CNTRL));
   if (!memcmp (s, "VER ", 4) &&
       (a = strstr (s, PRTCLNAME "/")) != 0 &&
       (b = strstr (a, ".")) != 0)
@@ -587,7 +585,7 @@ static int RError (STATE *state, char *buf, int sz)
 {
   char *s;
 
-  Log (1, "rerror: %s", s = strquote (buf));
+  Log (1, "rerror: %s", s = strquote (buf, SQ_CNTRL));
   if (state->to)
     bad_try (&state->to->fa, s);
   free (s);
@@ -598,7 +596,7 @@ static int BSY (STATE *state, char *buf, int sz)
 {
   char *s;
 
-  Log (1, "got M_BSY: %s", s = strquote (buf));
+  Log (1, "got M_BSY: %s", s = strquote (buf, SQ_CNTRL));
   if (state->to)
     bad_try (&state->to->fa, s);
   free (s);
@@ -618,7 +616,7 @@ static int ADR (STATE *state, char *s, int sz)
   {
     if (!parse_ftnaddress (w, &fa) || !is5D (&fa))
     {
-      char *q = strquote (s);
+      char *q = strquote (s, SQ_CNTRL);
 
       msg_send2 (state, M_ERR, "Bad address", 0);
       Log (1, "remote passed bad address: `%s'", q);
@@ -633,11 +631,13 @@ static int ADR (STATE *state, char *s, int sz)
     if (bsy_add (&fa, F_BSY))
     {
       Log (2, "addr: %s", szFTNAddr);
-      state->fa = realloc (state->fa, sizeof (FTN_ADDR) * ++state->nfa);
-
-      assert (state->fa != 0);
+      if (i == 1)
+	setproctitle ("%c %s [%s]",
+		      state->to ? 'o' : 'i',
+		      szFTNAddr,
+		      state->peer_name);
+      state->fa = xrealloc (state->fa, sizeof (FTN_ADDR) * ++state->nfa);
       memcpy (state->fa + state->nfa - 1, &fa, sizeof (FTN_ADDR));
-
       if (state->to &&
 	  !ftnaddress_cmp (state->fa + state->nfa - 1, &state->to->fa))
       {
@@ -1158,8 +1158,7 @@ static void banner (STATE *state)
   msg_sendf (state, M_NUL,
     "VER " MYNAME "/" MYVER "%s " PRTCLNAME "/" PRTCLVER, get_os_string ());
 
-  szAkas = malloc (nAddr * (FTN_ADDR_SZ + 1));
-  assert (szAkas != 0);
+  szAkas = xalloc (nAddr * (FTN_ADDR_SZ + 1));
   *szAkas = 0;
   for (i = 0; i < nAddr; ++i)
   {
@@ -1312,8 +1311,11 @@ void protocol (SOCKET socket, FTN_NODE *to)
   if (getpeername (socket, (struct sockaddr *) & peer_name, &peer_name_len) == -1)
     Log (1, "getpeername: %s", TCPERR ());
 
-  state.peer_name = strdup (get_hostname (&peer_name));
-  Log (2, "session with %s", state.peer_name);
+  state.peer_name = xstrdup (get_hostname (&peer_name));
+  setproctitle ("%c [%s]", to ? 'o' : 'i', state.peer_name);
+  Log (2, "session with %s (%s)",
+       state.peer_name,
+       inet_ntoa (peer_name.sin_addr));
 
   banner (&state);
   if (n_servers > max_servers)
